@@ -183,6 +183,7 @@ struct _GWebIface {
     gboolean (*get_plugin_enabled) (GWeb *self, gchar* name);
     GWebStatus (*set_plugin_enabled) (GWeb *self, gchar* name, gboolean enable);
     GWebStatus (*set_plugin_ignore_filepath) (GWeb *self);
+    void (*notify_service) (GWeb *self, const gchar *service_name, gpointer *context, const gchar *topic, gchar *data);
 };
 
 GType g_web_get_type (void);
@@ -639,6 +640,7 @@ void g_web_certificate_free (GWeb *self, GObject* cert);
   */
 void g_web_notify_plugins(GWeb *self, gint event);
 
+
 /** Get the number of stored username/password sets
   * stored for a forms element or all forms elements at a server.
   *
@@ -779,6 +781,15 @@ gboolean g_web_get_plugin_enabled (GWeb *self, gchar* name);
   */
 GWebStatus g_web_set_plugin_ignore_filepath (GWeb *self);
 
+/** Sends a event message to web
+  * @param self Object pointer
+  * @param service_name name of Web service
+  * @param context Some context pointer
+  * @param topic Topic name
+  * @param data Some gunichar data
+  */
+void g_web_notify_service(GWeb *self, const gchar *service_name, gpointer *context, const gchar *topic, gchar *data);
+
 /**
   * Global Signals.
   */
