@@ -428,13 +428,15 @@ typedef enum
 	G_WEBENGINE_ENCODING_CP_1258,
 	G_WEBENGINE_ENCODING_SHIFTJIS,
 	G_WEBENGINE_ENCODING_ISO2022_JP,
-	G_WEBENGINE_ENCODING_BIG5,
 	G_WEBENGINE_ENCODING_EUC_JP,
 	G_WEBENGINE_ENCODING_GB2312,
 	G_WEBENGINE_ENCODING_VISCII,
 	G_WEBENGINE_ENCODING_EUC_KR,
 	G_WEBENGINE_ENCODING_HZ_GB2312,
 	G_WEBENGINE_ENCODING_GBK,
+	G_WEBENGINE_ENCODING_GB_18030,
+	G_WEBENGINE_ENCODING_BIG5,
+	G_WEBENGINE_ENCODING_ISO_2022_CN,
 	G_WEBENGINE_ENCODING_EUC_TW,
 	G_WEBENGINE_ENCODING_WS2,
 	G_WEBENGINE_ENCODING_IBM866,
