@@ -171,7 +171,7 @@ struct _GWebEngineIface {
 	void (*notify_plugins) (GWebEngine *self, gint event);
 	void (*preload_current_skin) (GWebEngine *self);
 	void (*invoke_selectmatch) (GWebEngine *self);
-	GObject* (*get_server_certificate) (GWebEngine *self);
+	GArray* (*get_server_certificate) (GWebEngine *self, gpointer context);
 	gboolean (*is_engine_editable_widget) (GWebEngine *self);
 };
 
@@ -581,7 +581,7 @@ void g_web_engine_invoke_selectmatch(GWebEngine *self);
   *  
   * @return Returns the certificate.
   */
-GObject* g_web_engine_get_server_certificate (GWebEngine *self);
+GArray *g_web_engine_get_server_certificate (GWebEngine *self, gpointer context);
 
 G_END_DECLS
 
