@@ -212,6 +212,7 @@ void g_web_widget_signal_window_request(GObject * engine_widget,
                                         gpointer context,
 					const gchar *url,
 					gboolean in_background, 
+					gboolean unrequested,
 					GObject *browser_window);
 
 #define G_WEBWIDGET_SIGNAL_DOWNLOAD_REQUEST "download_request"
@@ -262,12 +263,11 @@ void g_web_widget_signal_lower_request(GObject *engine_widget,
   * @param filter The default filter
   * @param result Pointer to where the file name should be saved. The implementor must allocate the space with g_malloc, it will be freed inside Engine.
   *
-  * @return TRUE if OK was pressed
+  * @return string with the resulting filename
   */
-gboolean g_web_widget_signal_upload_dialog(GObject *engine_widget,
+gchar* g_web_widget_signal_upload_dialog(GObject *engine_widget,
                                 	    const gchar *path,
 					    const gchar *filter,
-					    gchar **result,
 					    GObject *browser_window);
 
 #define G_WEBWIDGET_SIGNAL_FILE_UPLOAD_STARTED "file_upload_started"
